@@ -14,7 +14,6 @@ from bitmovin_api_sdk.encoding.manifests.manifests_api import ManifestsApi
 from bitmovin_api_sdk.encoding.infrastructure.infrastructure_api import InfrastructureApi
 from bitmovin_api_sdk.encoding.statistics.statistics_api import StatisticsApi
 from bitmovin_api_sdk.encoding.watch_folders.watch_folders_api import WatchFoldersApi
-from bitmovin_api_sdk.encoding.simple.simple_api import SimpleApi
 from bitmovin_api_sdk.encoding.error_definitions.error_definitions_api import ErrorDefinitionsApi
 from bitmovin_api_sdk.encoding.templates.templates_api import TemplatesApi
 
@@ -101,13 +100,6 @@ class EncodingApi(BaseApi):
             logger=logger
         )
 
-        self.simple = SimpleApi(
-            api_key=api_key,
-            tenant_org_id=tenant_org_id,
-            base_url=base_url,
-            logger=logger
-        )
-
         self.error_definitions = ErrorDefinitionsApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
