@@ -5,7 +5,6 @@ from __future__ import absolute_import
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.dvb_subtitle.dvb_subtitle_api import DvbSubtitleApi
-from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.dvb_teletext.dvb_teletext_api import DvbTeletextApi
 
 
 class SubtitlesApi(BaseApi):
@@ -26,10 +25,3 @@ class SubtitlesApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
-
-        self.dvb_teletext = DvbTeletextApi(
-            api_key=api_key,
-            tenant_org_id=tenant_org_id,
-            base_url=base_url,
-            logger=logger
-        )
