@@ -1,10 +1,11 @@
 class SmoothStreamingManifestListQueryParams(object):
-    def __init__(self, offset=None, limit=None, encoding_id=None):
-        # type: (int, int, string_types) -> None
+    def __init__(self, offset=None, limit=None, sort=None, encoding_id=None):
+        # type: (int, int, string_types, string_types) -> None
         super(SmoothStreamingManifestListQueryParams, self).__init__()
 
         self.offset = offset
         self.limit = limit
+        self.sort = sort
         self.encoding_id = encoding_id
 
     @property
@@ -12,6 +13,7 @@ class SmoothStreamingManifestListQueryParams(object):
         types = {
             'offset': 'int',
             'limit': 'int',
+            'sort': 'string_types',
             'encoding_id': 'string_types'
         }
 
@@ -22,6 +24,7 @@ class SmoothStreamingManifestListQueryParams(object):
         attributes = {
             'offset': 'offset',
             'limit': 'limit',
+            'sort': 'sort',
             'encoding_id': 'encodingId'
         }
 
