@@ -2,13 +2,14 @@ from bitmovin_api_sdk.models import OutputType
 
 
 class OutputListQueryParams(object):
-    def __init__(self, offset=None, limit=None, name=None, type_=None):
-        # type: (int, int, string_types, OutputType) -> None
+    def __init__(self, offset=None, limit=None, name=None, sort=None, type_=None):
+        # type: (int, int, string_types, string_types, OutputType) -> None
         super(OutputListQueryParams, self).__init__()
 
         self.offset = offset
         self.limit = limit
         self.name = name
+        self.sort = sort
         self.type = type_
 
     @property
@@ -17,6 +18,7 @@ class OutputListQueryParams(object):
             'offset': 'int',
             'limit': 'int',
             'name': 'string_types',
+            'sort': 'string_types',
             'type': 'OutputType'
         }
 
@@ -28,6 +30,7 @@ class OutputListQueryParams(object):
             'offset': 'offset',
             'limit': 'limit',
             'name': 'name',
+            'sort': 'sort',
             'type': 'type'
         }
 
