@@ -44,10 +44,10 @@ from bitmovin_api_sdk.models.adaptation_set_type_response import AdaptationSetTy
 from bitmovin_api_sdk.models.adaptive_quant_mode import AdaptiveQuantMode
 from bitmovin_api_sdk.models.aes_encryption_drm import AesEncryptionDrm
 from bitmovin_api_sdk.models.aes_encryption_method import AesEncryptionMethod
-from bitmovin_api_sdk.models.ai_content_analysis import AiContentAnalysis
-from bitmovin_api_sdk.models.ai_content_analysis_asset_description import AiContentAnalysisAssetDescription
-from bitmovin_api_sdk.models.ai_content_analysis_automatic_ad_placement import AiContentAnalysisAutomaticAdPlacement
-from bitmovin_api_sdk.models.ai_content_analysis_features import AiContentAnalysisFeatures
+from bitmovin_api_sdk.models.ai_scene_analysis import AiSceneAnalysis
+from bitmovin_api_sdk.models.ai_scene_analysis_asset_description import AiSceneAnalysisAssetDescription
+from bitmovin_api_sdk.models.ai_scene_analysis_automatic_ad_placement import AiSceneAnalysisAutomaticAdPlacement
+from bitmovin_api_sdk.models.ai_scene_analysis_features import AiSceneAnalysisFeatures
 from bitmovin_api_sdk.models.ai_service import AiService
 from bitmovin_api_sdk.models.ai_service_provider import AiServiceProvider
 from bitmovin_api_sdk.models.akamai_account import AkamaiAccount
@@ -125,6 +125,7 @@ from bitmovin_api_sdk.models.api_error_definition import ApiErrorDefinition
 from bitmovin_api_sdk.models.applied_stream_settings import AppliedStreamSettings
 from bitmovin_api_sdk.models.aspect_mode import AspectMode
 from bitmovin_api_sdk.models.aspera_input import AsperaInput
+from bitmovin_api_sdk.models.atmosphere import Atmosphere
 from bitmovin_api_sdk.models.audio_adaptation_set import AudioAdaptationSet
 from bitmovin_api_sdk.models.audio_configuration import AudioConfiguration
 from bitmovin_api_sdk.models.audio_group import AudioGroup
@@ -184,6 +185,7 @@ from bitmovin_api_sdk.models.broadcast_ts_program_configuration import Broadcast
 from bitmovin_api_sdk.models.broadcast_ts_subtitle_input_stream_configuration import BroadcastTsSubtitleInputStreamConfiguration
 from bitmovin_api_sdk.models.broadcast_ts_transport_configuration import BroadcastTsTransportConfiguration
 from bitmovin_api_sdk.models.broadcast_ts_video_input_stream_configuration import BroadcastTsVideoInputStreamConfiguration
+from bitmovin_api_sdk.models.burn_in_subtitle_assa import BurnInSubtitleAssa
 from bitmovin_api_sdk.models.burn_in_subtitle_dvb_sub import BurnInSubtitleDvbSub
 from bitmovin_api_sdk.models.burn_in_subtitle_srt import BurnInSubtitleSrt
 from bitmovin_api_sdk.models.cache_control import CacheControl
@@ -207,6 +209,7 @@ from bitmovin_api_sdk.models.cenc_play_ready import CencPlayReady
 from bitmovin_api_sdk.models.cenc_widevine import CencWidevine
 from bitmovin_api_sdk.models.channel_layout import ChannelLayout
 from bitmovin_api_sdk.models.channels_attribute_for_audio import ChannelsAttributeForAudio
+from bitmovin_api_sdk.models.character import Character
 from bitmovin_api_sdk.models.check_output_permissions_request import CheckOutputPermissionsRequest
 from bitmovin_api_sdk.models.check_output_permissions_response import CheckOutputPermissionsResponse
 from bitmovin_api_sdk.models.chroma_location import ChromaLocation
@@ -230,6 +233,7 @@ from bitmovin_api_sdk.models.condition_attribute import ConditionAttribute
 from bitmovin_api_sdk.models.condition_operator import ConditionOperator
 from bitmovin_api_sdk.models.condition_type import ConditionType
 from bitmovin_api_sdk.models.conform_filter import ConformFilter
+from bitmovin_api_sdk.models.content import Content
 from bitmovin_api_sdk.models.content_protection import ContentProtection
 from bitmovin_api_sdk.models.convert_scc_caption import ConvertSccCaption
 from bitmovin_api_sdk.models.convert_scc_caption_web_vtt_settings import ConvertSccCaptionWebVttSettings
@@ -368,12 +372,12 @@ from bitmovin_api_sdk.models.encoding_statistics_vod import EncodingStatisticsVo
 from bitmovin_api_sdk.models.encoding_stats import EncodingStats
 from bitmovin_api_sdk.models.encoding_stream_input import EncodingStreamInput
 from bitmovin_api_sdk.models.encoding_stream_input_details import EncodingStreamInputDetails
-from bitmovin_api_sdk.models.encoding_template import EncodingTemplate
 from bitmovin_api_sdk.models.encoding_template_details import EncodingTemplateDetails
 from bitmovin_api_sdk.models.encoding_template_request import EncodingTemplateRequest
 from bitmovin_api_sdk.models.encoding_template_response import EncodingTemplateResponse
 from bitmovin_api_sdk.models.encoding_template_start_response import EncodingTemplateStartResponse
 from bitmovin_api_sdk.models.encoding_template_type import EncodingTemplateType
+from bitmovin_api_sdk.models.encoding_template_url_response import EncodingTemplateUrlResponse
 from bitmovin_api_sdk.models.encoding_type import EncodingType
 from bitmovin_api_sdk.models.encryption_mode import EncryptionMode
 from bitmovin_api_sdk.models.enhanced_deinterlace_auto_enable import EnhancedDeinterlaceAutoEnable
@@ -429,6 +433,7 @@ from bitmovin_api_sdk.models.he_aac_v1_audio_configuration import HeAacV1AudioCo
 from bitmovin_api_sdk.models.he_aac_v1_signaling import HeAacV1Signaling
 from bitmovin_api_sdk.models.he_aac_v2_audio_configuration import HeAacV2AudioConfiguration
 from bitmovin_api_sdk.models.he_aac_v2_signaling import HeAacV2Signaling
+from bitmovin_api_sdk.models.hls_input import HlsInput
 from bitmovin_api_sdk.models.hls_manifest import HlsManifest
 from bitmovin_api_sdk.models.hls_manifest_ad_marker_settings import HlsManifestAdMarkerSettings
 from bitmovin_api_sdk.models.hls_manifest_ad_marker_type import HlsManifestAdMarkerType
@@ -438,6 +443,7 @@ from bitmovin_api_sdk.models.hls_target_duration_rounding_mode import HlsTargetD
 from bitmovin_api_sdk.models.hls_version import HlsVersion
 from bitmovin_api_sdk.models.http_input import HttpInput
 from bitmovin_api_sdk.models.https_input import HttpsInput
+from bitmovin_api_sdk.models.iab_taxonomy import IABTaxonomy
 from bitmovin_api_sdk.models.i_frame_playlist import IFramePlaylist
 from bitmovin_api_sdk.models.id3_tag import Id3Tag
 from bitmovin_api_sdk.models.id3_tag_position_mode import Id3TagPositionMode
@@ -512,6 +518,7 @@ from bitmovin_api_sdk.models.live_standby_pool_status import LiveStandbyPoolStat
 from bitmovin_api_sdk.models.live_standby_pool_update import LiveStandbyPoolUpdate
 from bitmovin_api_sdk.models.local_input import LocalInput
 from bitmovin_api_sdk.models.local_output import LocalOutput
+from bitmovin_api_sdk.models.location import Location
 from bitmovin_api_sdk.models.manifest import Manifest
 from bitmovin_api_sdk.models.manifest_generator import ManifestGenerator
 from bitmovin_api_sdk.models.manifest_resource import ManifestResource
@@ -528,6 +535,7 @@ from bitmovin_api_sdk.models.media_stream import MediaStream
 from bitmovin_api_sdk.models.media_type import MediaType
 from bitmovin_api_sdk.models.message import Message
 from bitmovin_api_sdk.models.message_type import MessageType
+from bitmovin_api_sdk.models.metadata import Metadata
 from bitmovin_api_sdk.models.min_coding_unit_size import MinCodingUnitSize
 from bitmovin_api_sdk.models.mjpeg_video_configuration import MjpegVideoConfiguration
 from bitmovin_api_sdk.models.motion_search import MotionSearch
@@ -632,6 +640,7 @@ from bitmovin_api_sdk.models.quantization_group_size import QuantizationGroupSiz
 from bitmovin_api_sdk.models.rai_unit import RaiUnit
 from bitmovin_api_sdk.models.rate_distortion_level_for_quantization import RateDistortionLevelForQuantization
 from bitmovin_api_sdk.models.rate_distortion_penalty_mode import RateDistortionPenaltyMode
+from bitmovin_api_sdk.models.rating import Rating
 from bitmovin_api_sdk.models.raw_id3_tag import RawId3Tag
 from bitmovin_api_sdk.models.redundant_rtmp_input import RedundantRtmpInput
 from bitmovin_api_sdk.models.reprioritize_encoding_request import ReprioritizeEncodingRequest
@@ -659,6 +668,9 @@ from bitmovin_api_sdk.models.s3_signature_version import S3SignatureVersion
 from bitmovin_api_sdk.models.scale_filter import ScaleFilter
 from bitmovin_api_sdk.models.scaling_algorithm import ScalingAlgorithm
 from bitmovin_api_sdk.models.scc_caption import SccCaption
+from bitmovin_api_sdk.models.scene import Scene
+from bitmovin_api_sdk.models.scene_analysis_details_response import SceneAnalysisDetailsResponse
+from bitmovin_api_sdk.models.scene_object import SceneObject
 from bitmovin_api_sdk.models.scheduled_insertable_content import ScheduledInsertableContent
 from bitmovin_api_sdk.models.scheduled_insertable_content_status import ScheduledInsertableContentStatus
 from bitmovin_api_sdk.models.scheduling import Scheduling
@@ -666,6 +678,7 @@ from bitmovin_api_sdk.models.scte35_cue import Scte35Cue
 from bitmovin_api_sdk.models.scte35_trigger import Scte35Trigger
 from bitmovin_api_sdk.models.segmented_raw_muxing import SegmentedRawMuxing
 from bitmovin_api_sdk.models.segments_media_info import SegmentsMediaInfo
+from bitmovin_api_sdk.models.setting import Setting
 from bitmovin_api_sdk.models.sftp_input import SftpInput
 from bitmovin_api_sdk.models.sftp_output import SftpOutput
 from bitmovin_api_sdk.models.sidecar_error_mode import SidecarErrorMode
@@ -673,45 +686,6 @@ from bitmovin_api_sdk.models.sidecar_file import SidecarFile
 from bitmovin_api_sdk.models.sidecar_file_type import SidecarFileType
 from bitmovin_api_sdk.models.signature_type import SignatureType
 from bitmovin_api_sdk.models.signup_source import SignupSource
-from bitmovin_api_sdk.models.simple_encoding_live_cloud_region import SimpleEncodingLiveCloudRegion
-from bitmovin_api_sdk.models.simple_encoding_live_job_access_key_credentials import SimpleEncodingLiveJobAccessKeyCredentials
-from bitmovin_api_sdk.models.simple_encoding_live_job_azure_credentials import SimpleEncodingLiveJobAzureCredentials
-from bitmovin_api_sdk.models.simple_encoding_live_job_cdn_output import SimpleEncodingLiveJobCdnOutput
-from bitmovin_api_sdk.models.simple_encoding_live_job_credentials import SimpleEncodingLiveJobCredentials
-from bitmovin_api_sdk.models.simple_encoding_live_job_gcs_service_account_credentials import SimpleEncodingLiveJobGcsServiceAccountCredentials
-from bitmovin_api_sdk.models.simple_encoding_live_job_input import SimpleEncodingLiveJobInput
-from bitmovin_api_sdk.models.simple_encoding_live_job_input_type import SimpleEncodingLiveJobInputType
-from bitmovin_api_sdk.models.simple_encoding_live_job_output import SimpleEncodingLiveJobOutput
-from bitmovin_api_sdk.models.simple_encoding_live_job_output_type import SimpleEncodingLiveJobOutputType
-from bitmovin_api_sdk.models.simple_encoding_live_job_request import SimpleEncodingLiveJobRequest
-from bitmovin_api_sdk.models.simple_encoding_live_job_response import SimpleEncodingLiveJobResponse
-from bitmovin_api_sdk.models.simple_encoding_live_job_s3_role_based_credentials import SimpleEncodingLiveJobS3RoleBasedCredentials
-from bitmovin_api_sdk.models.simple_encoding_live_job_status import SimpleEncodingLiveJobStatus
-from bitmovin_api_sdk.models.simple_encoding_live_job_url_output import SimpleEncodingLiveJobUrlOutput
-from bitmovin_api_sdk.models.simple_encoding_live_job_username_password_credentials import SimpleEncodingLiveJobUsernamePasswordCredentials
-from bitmovin_api_sdk.models.simple_encoding_live_max_resolution import SimpleEncodingLiveMaxResolution
-from bitmovin_api_sdk.models.simple_encoding_live_profile import SimpleEncodingLiveProfile
-from bitmovin_api_sdk.models.simple_encoding_vod_job_access_key_credentials import SimpleEncodingVodJobAccessKeyCredentials
-from bitmovin_api_sdk.models.simple_encoding_vod_job_azure_credentials import SimpleEncodingVodJobAzureCredentials
-from bitmovin_api_sdk.models.simple_encoding_vod_job_cdn_output import SimpleEncodingVodJobCdnOutput
-from bitmovin_api_sdk.models.simple_encoding_vod_job_credentials import SimpleEncodingVodJobCredentials
-from bitmovin_api_sdk.models.simple_encoding_vod_job_direct_file_upload_input import SimpleEncodingVodJobDirectFileUploadInput
-from bitmovin_api_sdk.models.simple_encoding_vod_job_errors import SimpleEncodingVodJobErrors
-from bitmovin_api_sdk.models.simple_encoding_vod_job_gcs_service_account_credentials import SimpleEncodingVodJobGcsServiceAccountCredentials
-from bitmovin_api_sdk.models.simple_encoding_vod_job_input import SimpleEncodingVodJobInput
-from bitmovin_api_sdk.models.simple_encoding_vod_job_input_source_type import SimpleEncodingVodJobInputSourceType
-from bitmovin_api_sdk.models.simple_encoding_vod_job_input_type import SimpleEncodingVodJobInputType
-from bitmovin_api_sdk.models.simple_encoding_vod_job_options import SimpleEncodingVodJobOptions
-from bitmovin_api_sdk.models.simple_encoding_vod_job_output import SimpleEncodingVodJobOutput
-from bitmovin_api_sdk.models.simple_encoding_vod_job_output_artifact import SimpleEncodingVodJobOutputArtifact
-from bitmovin_api_sdk.models.simple_encoding_vod_job_output_type import SimpleEncodingVodJobOutputType
-from bitmovin_api_sdk.models.simple_encoding_vod_job_request import SimpleEncodingVodJobRequest
-from bitmovin_api_sdk.models.simple_encoding_vod_job_response import SimpleEncodingVodJobResponse
-from bitmovin_api_sdk.models.simple_encoding_vod_job_s3_role_based_credentials import SimpleEncodingVodJobS3RoleBasedCredentials
-from bitmovin_api_sdk.models.simple_encoding_vod_job_status import SimpleEncodingVodJobStatus
-from bitmovin_api_sdk.models.simple_encoding_vod_job_url_input import SimpleEncodingVodJobUrlInput
-from bitmovin_api_sdk.models.simple_encoding_vod_job_url_output import SimpleEncodingVodJobUrlOutput
-from bitmovin_api_sdk.models.simple_encoding_vod_job_username_password_credentials import SimpleEncodingVodJobUsernamePasswordCredentials
 from bitmovin_api_sdk.models.smooth_manifest_content_protection import SmoothManifestContentProtection
 from bitmovin_api_sdk.models.smooth_manifest_default import SmoothManifestDefault
 from bitmovin_api_sdk.models.smooth_manifest_default_version import SmoothManifestDefaultVersion
