@@ -66,8 +66,17 @@ class CloudRegion(Enum):
     AZURE_US_NORTH_CENTRAL = "AZURE_US_NORTH_CENTRAL"
     AZURE_UK_SOUTH = "AZURE_UK_SOUTH"
     AKAMAI_BR_GRU = "AKAMAI_BR_GRU"
+    AKAMAI_ES_MAD = "AKAMAI_ES_MAD"
     AKAMAI_FR_PAR = "AKAMAI_FR_PAR"
+    AKAMAI_ID_CGK = "AKAMAI_ID_CGK"
+    AKAMAI_IN_MAA = "AKAMAI_IN_MAA"
+    AKAMAI_IT_MIL = "AKAMAI_IT_MIL"
     AKAMAI_JP_OSA = "AKAMAI_JP_OSA"
+    AKAMAI_NL_AMS = "AKAMAI_NL_AMS"
+    AKAMAI_SE_STO = "AKAMAI_SE_STO"
+    AKAMAI_US_LAX = "AKAMAI_US_LAX"
+    AKAMAI_US_MIA = "AKAMAI_US_MIA"
+    AKAMAI_US_ORD = "AKAMAI_US_ORD"
     AKAMAI_US_SEA = "AKAMAI_US_SEA"
     OCI_EU_FRANKFURT_1 = "OCI_EU_FRANKFURT_1"
     OCI_US_ASHBURN_1 = "OCI_US_ASHBURN_1"
