@@ -12,20 +12,20 @@ import six
 class SpekeDrm(Drm):
     @poscheck_model
     def __init__(self,
+                 id_=None,
                  name=None,
                  description=None,
                  created_at=None,
                  modified_at=None,
                  custom_data=None,
-                 id_=None,
                  outputs=None,
                  content_id=None,
                  kid=None,
                  iv=None,
                  provider=None,
                  system_ids=None):
-        # type: (string_types, string_types, datetime, datetime, dict, string_types, list[EncodingOutput], string_types, string_types, string_types, SpekeDrmProvider, list[string_types]) -> None
-        super(SpekeDrm, self).__init__(name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, id_=id_, outputs=outputs)
+        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[EncodingOutput], string_types, string_types, string_types, SpekeDrmProvider, list[string_types]) -> None
+        super(SpekeDrm, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, outputs=outputs)
 
         self._content_id = None
         self._kid = None
